# warn-transformer

Consolidate, enrich and republish the data gathered by [warn-scraper](https://github.com/biglocalnews/warn-scraper)

## Installation

Use `pip` or `pipenv` to install the Python library and command-line interface.

```bash
pipenv install warn-transformer
```

## Table of contents

```{toctree}
:maxdepth: 1
:name: mastertoc

contributing
releasing
reference
```

## Links

- Documentation: [warn-transformer.readthedocs.io](https://warn-transformer.readthedocs.io)
- Repository: [github.com/biglocalnews/warn-transformer](https://github.com/biglocalnews/warn-transformer)
- Packaging: [pypi.org/project/warn-transformer](https://pypi.org/project/warn-transformer/)

## About

The project is sponsored by [Big Local News](https://biglocalnews.org/#/about), a program at Stanford University that collects data for impactful journalism. The code is maintained by [Ben Welsh](https://palewi.re/who-is-ben-welsh/), a visiting data journalist from the Los Angeles Times.
